@@ -4,11 +4,11 @@ from dodo_commands import Dodo
 
 
 def _args():  # noqa
-    parser = ArgumentParser(description=('Print hello world.'))
+    parser = ArgumentParser(description=("Print hello world."))
     args = Dodo.parse_args(parser)
     return args
 
 
 if Dodo.is_main(__name__):
     args = _args()
-    Dodo.run(['echo', 'Hello world'])
+    Dodo.run(["echo", "Hello world"])
