@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 """Utilities."""
 import os
+import re
 import sys
 
 from dodo_commands.dependencies.get import plumbum, six
@@ -147,6 +148,14 @@ def maybe_list_to_list(maybe_list):
     return maybe_list if isinstance(maybe_list, list) else [maybe_list]
 
 
+def to_arg_list(x):
+    if isinstance(x, str):
+        if re.match(r"'.*'", x) or re.match(r'".*"', x):
+            x = x[1:-1]
+        x = x.split()
+    return maybe_list_to_list(x or [])
+
+
 def sh_cmd(cmd):
     return ["sh", "-c", cmd]
 
